==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cfg/kotlin/OrganizationCustomPolicyRule.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cfg.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List

/**
 * Builder for [OrganizationCustomPolicyRule].
 */
@PulumiTagMarker
public class OrganizationCustomPolicyRuleResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: OrganizationCustomPolicyRuleArgs = OrganizationCustomPolicyRuleArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend OrganizationCustomPolicyRuleArgsBuilder.() -> Unit) {
        val builder = OrganizationCustomPolicyRuleArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): OrganizationCustomPolicyRule {
        val builtJavaResource = com.pulumi.aws.cfg.OrganizationCustomPolicyRule(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return OrganizationCustomPolicyRule(builtJavaResource)
    }
}

/**
 * Manages a Config Organization Custom Policy Rule. More information about these rules can be found in the [Enabling AWS Config Rules Across all Accounts in Your Organization](https://docs&#46;aws&#46;amazon&#46;com/config/latest/developerguide/config-rule-multi-account-deployment&#46;html) and [AWS Config Managed Rules](https://docs.aws.amazon.com/config/latest/developerguide/evaluate-config_use-managed-rules.html) documentation. For working with Organization Managed Rules (those invoking an AWS managed rule), see the `aws_config_organization_managed__rule` resource.
 * > **NOTE:** This resource must be created in the Organization master account and rules will include the master account unless its ID is added to the `excluded_accounts` argument.
 * ## Example Usage
 * ### Basic Usage
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.cfg.OrganizationCustomPolicyRule;
 * import com.pulumi.aws.cfg.OrganizationCustomPolicyRuleArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var example = new OrganizationCustomPolicyRule("example", OrganizationCustomPolicyRuleArgs.builder()
 *             .policyRuntime("guard-2.x.x")
 *             .policyText("""
 *   let status = ['ACTIVE']
 *   rule tableisactive when
 *       resourceType == "AWS::DynamoDB::Table" {
 *       configuration.tableStatus == %status
 *   }
 *   rule checkcompliance when
 *       resourceType == "AWS::DynamoDB::Table"
 *       tableisactive {
 *           let pitr = supplementaryConfiguration.ContinuousBackupsDescription.pointInTimeRecoveryDescription.pointInTimeRecoveryStatus
 *           %pitr == "ENABLED"
 *       }
 *             """)
 *             .resourceTypesScopes("AWS::DynamoDB::Table")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * Using `pulumi import`, import a Config Organization Custom Policy Rule using the `name` argument. For example:
 * ```sh
 *  $ pulumi import aws:cfg/organizationCustomPolicyRule:OrganizationCustomPolicyRule example example_rule_name
 * ```
 *
 */
public class OrganizationCustomPolicyRule internal constructor(
    override val javaResource: com.pulumi.aws.cfg.OrganizationCustomPolicyRule,
) : KotlinCustomResource(javaResource, OrganizationCustomPolicyRuleMapper) {
    /**
     * Amazon Resource Name (ARN) of the rule
     */
    public val arn: Output<String>
        get() = javaResource.arn().applyValue({ args0 -> args0 })

    /**
     * List of AWS account identifiers to exclude from the rule
     */
    public val debugLogDeliveryAccounts: Output<List<String>>?
        get() = javaResource.debugLogDeliveryAccounts().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })

    /**
     * Description of the rule
     */
    public val description: Output<String>?
        get() = javaResource.description().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * List of AWS account identifiers to exclude from the rule
     */
    public val excludedAccounts: Output<List<String>>?
        get() = javaResource.excludedAccounts().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })

    /**
     * A string in JSON format that is passed to the AWS Config Rule Lambda Function
     */
    public val inputParameters: Output<String>?
        get() = javaResource.inputParameters().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Maximum frequency with which AWS Config runs evaluations for a rule, if the rule is triggered at a periodic frequency. Defaults to `TwentyFour_Hours` for periodic frequency triggered rules. Valid values: `One_Hour`, `Three_Hours`, `Six_Hours`, `Twelve_Hours`, or `TwentyFour_Hours`.
     */
    public val maximumExecutionFrequency: Output<String>?
        get() = javaResource.maximumExecutionFrequency().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * name of the rule
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * runtime system for your organization AWS Config Custom Policy rules
     */
    public val policyRuntime: Output<String>
        get() = javaResource.policyRuntime().applyValue({ args0 -> args0 })

    /**
     * policy definition containing the logic for your organization AWS Config Custom Policy rule
     */
    public val policyText: Output<String>
        get() = javaResource.policyText().applyValue({ args0 -> args0 })

    /**
     * Identifier of the AWS resource to evaluate
     */
    public val resourceIdScope: Output<String>?
        get() = javaResource.resourceIdScope().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * List of types of AWS resources to evaluate
     */
    public val resourceTypesScopes: Output<List<String>>?
        get() = javaResource.resourceTypesScopes().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })

    /**
     * Tag key of AWS resources to evaluate
     */
    public val tagKeyScope: Output<String>?
        get() = javaResource.tagKeyScope().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Tag value of AWS resources to evaluate
     */
    public val tagValueScope: Output<String>?
        get() = javaResource.tagValueScope().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * List of notification types that trigger AWS Config to run an evaluation for the rule. Valid values: `ConfigurationItemChangeNotification`, `OversizedConfigurationItemChangeNotification`
     * The following arguments are optional:
     */
    public val triggerTypes: Output<List<String>>
        get() = javaResource.triggerTypes().applyValue({ args0 -> args0.map({ args0 -> args0 }) })
}

public object OrganizationCustomPolicyRuleMapper : ResourceMapper<OrganizationCustomPolicyRule> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.aws.cfg.OrganizationCustomPolicyRule::class == javaResource::class

    override fun map(javaResource: Resource): OrganizationCustomPolicyRule =
        OrganizationCustomPolicyRule(javaResource as com.pulumi.aws.cfg.OrganizationCustomPolicyRule)
}

/**
 * @see [OrganizationCustomPolicyRule].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [OrganizationCustomPolicyRule].
 */
public suspend fun organizationCustomPolicyRule(
    name: String,
    block: suspend OrganizationCustomPolicyRuleResourceBuilder.() -> Unit,
):
    OrganizationCustomPolicyRule {
    val builder = OrganizationCustomPolicyRuleResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [OrganizationCustomPolicyRule].
 * @param name The _unique_ name of the resulting resource.
 */
public fun organizationCustomPolicyRule(name: String): OrganizationCustomPolicyRule {
    val builder = OrganizationCustomPolicyRuleResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cfg/kotlin/OrganizationCustomPolicyRule.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cfg.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List

/**
 * Builder for [OrganizationCustomPolicyRule].
 */
@PulumiTagMarker
public class OrganizationCustomPolicyRuleResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: OrganizationCustomPolicyRuleArgs = OrganizationCustomPolicyRuleArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend OrganizationCustomPolicyRuleArgsBuilder.() -> Unit) {
        val builder = OrganizationCustomPolicyRuleArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): OrganizationCustomPolicyRule {
        val builtJavaResource = com.pulumi.aws.cfg.OrganizationCustomPolicyRule(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return OrganizationCustomPolicyRule(builtJavaResource)
    }
}

/**
 * Manages a Config Organization Custom Policy Rule. More information about these rules can be found in the [Enabling AWS Config Rules Across all Accounts in Your Organization](https://docs&#46;aws&#46;amazon&#46;com/config/latest/developerguide/config-rule-multi-account-deployment&#46;html) and [AWS Config Managed Rules](https://docs.aws.amazon.com/config/latest/developerguide/evaluate-config_use-managed-rules.html) documentation. For working with Organization Managed Rules (those invoking an AWS managed rule), see the `aws_config_organization_managed__rule` resource.
 * > **NOTE:** This resource must be created in the Organization master account and rules will include the master account unless its ID is added to the `excluded_accounts` argument.
 * ## Example Usage
 * ### Basic Usage
 * <!--Start PulumiCodeChooser -->
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * const example = new aws.cfg.OrganizationCustomPolicyRule("example", {
 *     name: "example_rule_name",
 *     policyRuntime: "guard-2.x.x",
 *     policyText: `let status = ['ACTIVE']
 * rule tableisactive when
 *     resourceType == "AWS::DynamoDB::Table" {
 *     configuration.tableStatus == %status
 * }
 * rule checkcompliance when
 *     resourceType == "AWS::DynamoDB::Table"
 *     tableisactive {
 *         let pitr = supplementaryConfiguration.ContinuousBackupsDescription.pointInTimeRecoveryDescription.pointInTimeRecoveryStatus
 *         %pitr == "ENABLED"
 *     }
 * `,
 *     resourceTypesScopes: ["AWS::DynamoDB::Table"],
 * });
 * ```
 * ```python
 * import pulumi
 * import pulumi_aws as aws
 * example = aws.cfg.OrganizationCustomPolicyRule("example",
 *     name="example_rule_name",
 *     policy_runtime="guard-2.x.x",
 *     policy_text="""let status = ['ACTIVE']
 * rule tableisactive when
 *     resourceType == "AWS::DynamoDB::Table" {
 *     configuration.tableStatus == %status
 * }
 * rule checkcompliance when
 *     resourceType == "AWS::DynamoDB::Table"
 *     tableisactive {
 *         let pitr = supplementaryConfiguration.ContinuousBackupsDescription.pointInTimeRecoveryDescription.pointInTimeRecoveryStatus
 *         %pitr == "ENABLED"
 *     }
 * """,
 *     resource_types_scopes=["AWS::DynamoDB::Table"])
 * ```
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using Aws = Pulumi.Aws;
 * return await Deployment.RunAsync(() =>
 * {
 *     var example = new Aws.Cfg.OrganizationCustomPolicyRule("example", new()
 *     {
 *         Name = "example_rule_name",
 *         PolicyRuntime = "guard-2.x.x",
 *         PolicyText = @"let status = ['ACTIVE']
 * rule tableisactive when
 *     resourceType == ""AWS::DynamoDB::Table"" {
 *     configuration.tableStatus == %status
 * }
 * rule checkcompliance when
 *     resourceType == ""AWS::DynamoDB::Table""
 *     tableisactive {
 *         let pitr = supplementaryConfiguration.ContinuousBackupsDescription.pointInTimeRecoveryDescription.pointInTimeRecoveryStatus
 *         %pitr == ""ENABLED""
 *     }
 * ",
 *         ResourceTypesScopes = new[]
 *         {
 *             "AWS::DynamoDB::Table",
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/cfg"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := cfg.NewOrganizationCustomPolicyRule(ctx, "example", &cfg.OrganizationCustomPolicyRuleArgs{
 * 			Name:          pulumi.String("example_rule_name"),
 * 			PolicyRuntime: pulumi.String("guard-2.x.x"),
 * 			PolicyText: pulumi.String(`let status = ['ACTIVE']
 * rule tableisactive when
 *     resourceType == "AWS::DynamoDB::Table" {
 *     configuration.tableStatus == %status
 * }
 * rule checkcompliance when
 *     resourceType == "AWS::DynamoDB::Table"
 *     tableisactive {
 *         let pitr = supplementaryConfiguration.ContinuousBackupsDescription.pointInTimeRecoveryDescription.pointInTimeRecoveryStatus
 *         %pitr == "ENABLED"
 *     }
 * `),
 * 			ResourceTypesScopes: pulumi.StringArray{
 * 				pulumi.String("AWS::DynamoDB::Table"),
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.cfg.OrganizationCustomPolicyRule;
 * import com.pulumi.aws.cfg.OrganizationCustomPolicyRuleArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var example = new OrganizationCustomPolicyRule("example", OrganizationCustomPolicyRuleArgs.builder()
 *             .name("example_rule_name")
 *             .policyRuntime("guard-2.x.x")
 *             .policyText("""
 * let status = ['ACTIVE']
 * rule tableisactive when
 *     resourceType == "AWS::DynamoDB::Table" {
 *     configuration.tableStatus == %status
 * }
 * rule checkcompliance when
 *     resourceType == "AWS::DynamoDB::Table"
 *     tableisactive {
 *         let pitr = supplementaryConfiguration.ContinuousBackupsDescription.pointInTimeRecoveryDescription.pointInTimeRecoveryStatus
 *         %pitr == "ENABLED"
 *     }
 *             """)
 *             .resourceTypesScopes("AWS::DynamoDB::Table")
 *             .build());
 *     }
 * }
 * ```
 * ```yaml
 * resources:
 *   example:
 *     type: aws:cfg:OrganizationCustomPolicyRule
 *     properties:
 *       name: example_rule_name
 *       policyRuntime: guard-2.x.x
 *       policyText: |
 *         let status = ['ACTIVE']
 *         rule tableisactive when
 *             resourceType == "AWS::DynamoDB::Table" {
 *             configuration.tableStatus == %status
 *         }
 *         rule checkcompliance when
 *             resourceType == "AWS::DynamoDB::Table"
 *             tableisactive {
 *                 let pitr = supplementaryConfiguration.ContinuousBackupsDescription.pointInTimeRecoveryDescription.pointInTimeRecoveryStatus
 *                 %pitr == "ENABLED"
 *             }
 *       resourceTypesScopes:
 *         - AWS::DynamoDB::Table
 * ```
 * <!--End PulumiCodeChooser -->
 * ## Import
 * Using `pulumi import`, import a Config Organization Custom Policy Rule using the `name` argument. For example:
 * ```sh
 * $ pulumi import aws:cfg/organizationCustomPolicyRule:OrganizationCustomPolicyRule example example_rule_name
 * ```
 */
public class OrganizationCustomPolicyRule internal constructor(
    override val javaResource: com.pulumi.aws.cfg.OrganizationCustomPolicyRule,
) : KotlinCustomResource(javaResource, OrganizationCustomPolicyRuleMapper) {
    /**
     * Amazon Resource Name (ARN) of the rule
     */
    public val arn: Output<String>
        get() = javaResource.arn().applyValue({ args0 -> args0 })

    /**
     * List of AWS account identifiers to exclude from the rule
     */
    public val debugLogDeliveryAccounts: Output<List<String>>?
        get() = javaResource.debugLogDeliveryAccounts().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })

    /**
     * Description of the rule
     */
    public val description: Output<String>?
        get() = javaResource.description().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * List of AWS account identifiers to exclude from the rule
     */
    public val excludedAccounts: Output<List<String>>?
        get() = javaResource.excludedAccounts().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })

    /**
     * A string in JSON format that is passed to the AWS Config Rule Lambda Function
     */
    public val inputParameters: Output<String>?
        get() = javaResource.inputParameters().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Maximum frequency with which AWS Config runs evaluations for a rule, if the rule is triggered at a periodic frequency. Defaults to `TwentyFour_Hours` for periodic frequency triggered rules. Valid values: `One_Hour`, `Three_Hours`, `Six_Hours`, `Twelve_Hours`, or `TwentyFour_Hours`.
     */
    public val maximumExecutionFrequency: Output<String>?
        get() = javaResource.maximumExecutionFrequency().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * name of the rule
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * runtime system for your organization AWS Config Custom Policy rules
     */
    public val policyRuntime: Output<String>
        get() = javaResource.policyRuntime().applyValue({ args0 -> args0 })

    /**
     * policy definition containing the logic for your organization AWS Config Custom Policy rule
     */
    public val policyText: Output<String>
        get() = javaResource.policyText().applyValue({ args0 -> args0 })

    /**
     * Identifier of the AWS resource to evaluate
     */
    public val resourceIdScope: Output<String>?
        get() = javaResource.resourceIdScope().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * List of types of AWS resources to evaluate
     */
    public val resourceTypesScopes: Output<List<String>>?
        get() = javaResource.resourceTypesScopes().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })

    /**
     * Tag key of AWS resources to evaluate
     */
    public val tagKeyScope: Output<String>?
        get() = javaResource.tagKeyScope().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Tag value of AWS resources to evaluate
     */
    public val tagValueScope: Output<String>?
        get() = javaResource.tagValueScope().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * List of notification types that trigger AWS Config to run an evaluation for the rule. Valid values: `ConfigurationItemChangeNotification`, `OversizedConfigurationItemChangeNotification`
     * The following arguments are optional:
     */
    public val triggerTypes: Output<List<String>>
        get() = javaResource.triggerTypes().applyValue({ args0 -> args0.map({ args0 -> args0 }) })
}

public object OrganizationCustomPolicyRuleMapper : ResourceMapper<OrganizationCustomPolicyRule> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.aws.cfg.OrganizationCustomPolicyRule::class == javaResource::class

    override fun map(javaResource: Resource): OrganizationCustomPolicyRule =
        OrganizationCustomPolicyRule(javaResource as com.pulumi.aws.cfg.OrganizationCustomPolicyRule)
}

/**
 * @see [OrganizationCustomPolicyRule].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [OrganizationCustomPolicyRule].
 */
public suspend fun organizationCustomPolicyRule(
    name: String,
    block: suspend OrganizationCustomPolicyRuleResourceBuilder.() -> Unit,
): OrganizationCustomPolicyRule {
    val builder = OrganizationCustomPolicyRuleResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [OrganizationCustomPolicyRule].
 * @param name The _unique_ name of the resulting resource.
 */
public fun organizationCustomPolicyRule(name: String): OrganizationCustomPolicyRule {
    val builder = OrganizationCustomPolicyRuleResourceBuilder()
    builder.name(name)
    return builder.build()
}
